{% extends 'campl.html' %}
{% load static %}
{% block campl_block_head %}
{% include 'campl-jquery-ui-block-head.html' %}
{% endblock %}
{% block campl_foot_js %}
{% include 'campl-jquery-ui-foot-js.html' %}
{% endblock %}