{% load static %}
{# moved jquery to <head> #}
    <script type="text/javascript" src="{% static 'javascripts/libs/ios-orientationchange-fix.js' %}"></script>
    <script type="text/javascript" src="{% static 'javascripts/libs/modernizr.js' %}"></script>
    <script type="text/javascript" src="{% static 'javascripts/custom.js' %}"></script>