{% load static %}
{# assume this will be included in apps which already include jquery #}
{# if not, don't forget to include jquery! #}
<link rel="stylesheet" href="{% static 'css/campl-turquoise/jquery-ui-1.10.1.custom.min.css' %}" />
<script type="text/javascript" src="{% static 'js/jquery-ui-1.10.1.custom.min.js' %}"></script>